@@ -58,9 +58,9 @@ class ComplexityIndex():
         if self.reduce_function is None:
             self.reduce_function_abbr =  '' 
         elif self.reduce_function is average:
-            self.reduce_function_abbr = 'Avg'
+            self.reduce_function_abbr = 'M'
         elif self.reduce_function is standard_deviation:
-            self.reduce_function_abbr =  'StDev'
+            self.reduce_function_abbr =  'SD'
         elif self.reduce_function is maximum:
             self.reduce_function_abbr = 'Max'
         self.reduce_depth_abbr = '' if self.reduce_depth is None else self.element_to_abr(
@@ -72,6 +72,8 @@ class ComplexityIndex():
                 return el_type
 
     def element_to_abr(self, s) -> str:
+        if s == 'BLOCK':
+            return 'Par'
         return s[0].upper() + s[1:].lower()
 
     # overwritten by each index
@@ -80,7 +82,7 @@ class ComplexityIndex():
 
     # overwritten by each index 
     def __repr__(self):
-        return self.reduce_function_abbr + self.reduce_depth_abbr + self.abbr
+        return f"{self.reduce_function_abbr}({self.abbr} / {self.reduce_depth_abbr})"
 
     def __eq__(self, value):
         return repr(self) == repr(value)
