@@ -49,4 +49,4 @@ class PosMain(ComplexityIndex):
         return values
 
     def __repr__(self):
-        return self.reduce_function_abbr + self.reduce_depth_abbr + self.abbr + "_" + self.pos_type.name.lower()
+        return f"{self.reduce_function_abbr}({self.abbr}_{self.pos_type.name.lower()} / {self.reduce_depth_abbr})"
