@@ -52,4 +52,4 @@ class NoNamedEntity(ComplexityIndex):
         return values
     
     def __repr__(self):
-        return self.reduce_function_abbr + self.reduce_depth_abbr + self.abbr + "_" + self.named_ent_type.name.lower()
\ No newline at end of file
+        return f"{self.reduce_function_abbr}({self.abbr}_{self.named_ent_type.name.lower()} / {self.reduce_depth_abbr})"
