@@ -17,7 +17,7 @@ class WdDiffLemma(ComplexityIndex):
             reduce_function: MeasureFunction):
 
         ComplexityIndex.__init__(self, lang=lang, category=IndexCategory.WORD,
-                                 abbr="WdDiffLemma", reduce_depth=reduce_depth,
+                                 abbr="LemmaDiff", reduce_depth=reduce_depth,
                                  reduce_function=reduce_function)
 
     def process(self, element: TextElement) -> float:
